@@ -14,29 +14,28 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Command line parser for the Caliban app."""
+import argparse
 import os
 import sys
-import argparse
 from argparse import REMAINDER
 from typing import Any, Dict, List, Optional, Union
 
 import google.auth._cloud_sdk as csdk
 from absl.flags import argparse_flags
-from blessings import Terminal
 
-import caliban.cloud.types as ct
 import caliban.config as conf
-import caliban.docker as docker
+import caliban.config.experiment as ce
+import caliban.docker.build as b
+import caliban.platform.cloud.types as ct
+import caliban.platform.gke as gke
+import caliban.platform.gke.constants as gke_k
+import caliban.platform.gke.types as gke_t
+import caliban.platform.gke.util as gke_u
 import caliban.util as u
-import caliban.gke as gke
-import caliban.gke.constants as gke_k
-import caliban.gke.utils as gke_u
-import caliban.gke.types as gke_t
-
+import caliban.util.argparse as ua
+import caliban.util.schema as us
 from caliban import __version__
 
-t = Terminal()
-
 
 def _job_mode(use_gpu: bool, gpu_spec: Optional[ct.GPUSpec],
               tpu_spec: Optional[ct.TPUSpec]) -> conf.JobMode:
@@ -127,7 +126,7 @@ any arguments after '--' will pass through.""")
 def require_module(parser):
   parser.add_argument(
       "module",
-      type=u.validated_package,
+      type=ua.validated_package,
       help=
       "Code to execute, in either trainer.train' or 'trainer/train.py' format. "
       "Accepts python scripts, modules or a path to an arbitrary script.")
@@ -149,7 +148,7 @@ def no_cache_arg(parser):
 def docker_run_arg(parser):
   """Adds a command that accepts arguments to pass directly to `docker run`."""
   parser.add_argument("--docker_run_args",
-                      type=lambda s: s.split(" "),
+                      type=lambda s: s.split(),
                       help="String of args to add to Docker.")
 
 
@@ -158,7 +157,7 @@ def extra_dirs(parser):
       "-d",
       "--dir",
       action="append",
-      type=u.validated_directory,
+      type=ua.argparse_schema(us.Directory),
       help="Extra directories to include. List these from large to small "
       "to take full advantage of Docker's build cache.")
 
@@ -190,7 +189,7 @@ def region_arg(parser):
 
 def cloud_key_arg(parser):
   parser.add_argument("--cloud_key",
-                      type=u.validated_file,
+                      type=ua.argparse_schema(us.File),
                       help="Path to GCloud service account key. "
                       "(Defaults to $GOOGLE_APPLICATION_CREDENTIALS.)")
 
@@ -264,8 +263,8 @@ def shell_parser(base):
   docker_run_arg(parser)
   parser.add_argument(
       "--shell",
-      choices=docker.Shell,
-      type=docker.Shell,
+      choices=b.Shell,
+      type=b.Shell,
       help=
       """This argument sets the shell used inside the container to one of Caliban's
 supported shells. Defaults to the shell specified by the $SHELL environment
@@ -353,7 +352,7 @@ def job_name_arg(parser):
 def experiment_config_arg(parser):
   parser.add_argument(
       "--experiment_config",
-      type=conf.load_experiment_config,
+      type=ce.load_experiment_config,
       help="Path to an experiment config, or 'stdin' to read from stdin.")
 
 
@@ -362,7 +361,7 @@ def label_arg(parser):
                       "--label",
                       metavar="KEY=VALUE",
                       action="append",
-                      type=u.parse_kv_pair,
+                      type=ua.parse_kv_pair,
                       help="Extra label k=v pair to submit to Cloud.")
 
 
@@ -374,7 +373,6 @@ def dry_run_arg(parser):
 
 
 def container_parser(parser):
-
   executing_parser(parser)
 
   image_tag_arg(parser)
@@ -460,9 +458,9 @@ def _validate_machine_type(gpu_spec: Optional[ct.GPUSpec],
       # prefixes stick together.
       allowed = u.enum_vals(gpu_spec.allowed_machine_types())
       allowed.sort()
-      u.err("\n'{}' isn't a valid machine type ".format(machine_type.value) +
-            "for {} {} GPUs.\n\n".format(gpu_spec.count, gpu_spec.gpu.name))
-      u.err(ct.with_gpu_advice_suffix("Try one of these: {}".format(allowed)))
+      u.err(f"\n'{machine_type.value}' isn't a valid machine type " +
+            f"for {gpu_spec.count} {gpu_spec.gpu.name} GPUs.\n\n")
+      u.err(ct.with_advice_suffix("gpu", f"Try one of these: {allowed}"))
       u.err("\n")
       sys.exit(1)
 
@@ -540,7 +538,7 @@ def generate_docker_args(job_mode: conf.JobMode,
 
   # Get extra dependencies in case you want to install your requirements via a
   # setup.py file.
-  setup_extras = docker.base_extras(job_mode, "setup.py", args.get("extras"))
+  setup_extras = b.base_extras(job_mode, "setup.py", args.get("extras"))
 
   # Google application credentials, from the CLI or from an env variable.
   creds_path = conf.extract_cloud_key(args)
@@ -553,7 +551,7 @@ def generate_docker_args(job_mode: conf.JobMode,
   reqs = "requirements.txt"
   conda_env = "environment.yml"
 
-  # Arguments that make their way down to caliban.docker.build_image.
+  # Arguments that make their way down to caliban.docker.build.build_image.
   docker_args = {
       "extra_dirs": args.get("dir"),
       "requirements_path": reqs if os.path.exists(reqs) else None,
